import json
import logging
import smtplib
import sys
import time
import traceback
import datetime
import os
import random
from email.mime.application import MIMEApplication
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.utils import formataddr
import re
import pandas as pd
import requests
from lxml import etree
from pypinyin import lazy_pinyin

logger = logging.getLogger(__name__)


def send_email_tome():
    try:
        from_addrs = 'lixiaofang@igengmei.com'
        password = 'EzJzSRyEG4Jibuy9'
        toaddrs = "lixiaofang@igengmei.com"

        content = '爬取新氧热搜前100的词召回的商品，内容详见表格'
        text_apart = MIMEText(content, 'plain', "utf-8")

        zip_file_week = 'result1.csv'
        zip_apart_week = MIMEApplication(open(zip_file_week, 'rb').read())
        zip_apart_week.add_header('Content-Disposition', 'attachment', filename=zip_file_week)

        m = MIMEMultipart()
        m.attach(text_apart)
        m.attach(zip_apart_week)

        m['From'] = formataddr(("李小芳", from_addrs))
        m["To"] = formataddr(("李小芳", toaddrs))
        m['Subject'] = '新氧商品信息'

        try:
            server = smtplib.SMTP_SSL('smtp.exmail.qq.com', 465)
            server.login(from_addrs, password)
            server.sendmail(from_addrs, [toaddrs], m.as_string())
            print('success')
            server.quit()

        except smtplib.SMTPException as e:
            print('error', e)

    except Exception as e:
        print(str(e))
        logger.error("catch exception,main:%s" % traceback.format_exc())


def get_keynote_sentence(content):
    try:
        content_list = []
        ss = content.encode('utf-16', 'surrogatepass').decode('utf-16')
        dr = re.compile(r"<[^>]+>", re.S)
        str_re = dr.sub("", ss)
        para = re.sub('([；。！？\?])([^”’])', r"\1\n\2", str_re)  # 单字符断句符
        para = re.sub('(\.{6})([^”’])', r"\1\n\2", para)  # 英文省略号
        para = re.sub('(\…{2})([^”’])', r"\1\n\2", para)  # 中文省略号
        para = re.sub('([；。！？\?][”’])([^，。！？\?])', r'\1\n\2', para)
        para = para.rstrip()  # 段尾如果有多余的\n就去掉它
        return para
    except:
        logging.error("catch exception,logins:%s" % traceback.format_exc())
        return []


def get_service_info(query="", city_name="", get_data_file=None):
    print("get_service_info")
    break_flat = False
    other_city_count = 0
    for page in range(0, 3000, 10):
        if break_flat == False and other_city_count < 100:
            s = random.random()
            time.sleep(s)
            url = 'https://backend.igengmei.com/api/janus/search/v7/content?platform=iPhone&os_version=13.6.1&version=7.46.0&model=iphone%20X%20++&release=1&idfa=057F28DF-20B8-488F-A285-931367FCC110&idfv=74FE9CFB-DAD2-4379-B8F8-FC656F38BCA5&device_id=057F28DF-20B8-488F-A285-931367FCC110&uqid=47517624-F42B-469C-96EC-3BF936E44613&channel=App%20Store&app_name=gengmeiios&current_city_id={}&lat=39.98323941854652&lng=116.4880417854629&is_WiFi=1&hardware_model=iPhone12,1&ua=Mozilla/5.0%20(iPhone;%20CPU%20iPhone%20OS%2013_6_1%20like%20Mac%20OS%20X)%20AppleWebKit/605.1.15%20(KHTML,%20like%20Gecko)%20Mobile/15E148&sm_idfa=(null)&trace_id=2021/07/22/0956/53f8f1c10868&area_id=worldwide&count=10&is_first=1&is_gray=1&max_price=100000&min_price=0&offset={}&order_by=0&query={}&show_mode=1&size=10&tab_type=0'.format(
                city_name, page, query)
            response_res = requests.get(url, verify=False)
            if response_res.status_code == 200 and response_res.text:
                response = json.loads(response_res.text)
                responseData = response.get("data", {}).get("cards")
                for item in responseData:
                    if item.get("title") == "商品":
                        if len(item.get("feed", [])):
                            for service_data in item.get("feed", []):
                                city_id = service_data.get("hospital_info", {}).get("city_id")
                                if str(city_id) == str(city_name):
                                    # print(service_data)
                                    service_info = dict()
                                    service_info['skuid'] = service_data.get("service_item_id")
                                    service_info['美购id'] = service_data.get("service_id")
                                    service_info['医生名称'] = service_data.get("doctor_info", {}).get("name")
                                    service_info['医院名称'] = service_data.get("doctor_hospital_name")
                                    service_info['sku原价'] = service_data.get("price_info", {}).get(
                                        "original_payment_desc")
                                    service_info['sku活动价'] = service_data.get("price_info", {}).get(
                                        "total_payment_desc")
                                    # service_info['机构等级'] = service_data.get("avg_score")
                                    service_info['美购名称'] = get_keynote_sentence(service_data.get("title"))
                                    service_info['销量'] = service_data.get("sell_num_desc", 0)
                                    service_info['可用尾款券'] = []
                                    service_info['可领取预约金优惠券'] = []
                                    icon_data = service_data.get("sales_info", [])
                                    # print(icon_data)
                                    for sales_item in icon_data:
                                        if int(sales_item.get("type")) == 1 or int(sales_item.get("type")) == 3:
                                            service_info['可用尾款券'].append(sales_item.get("desc"))
                                        elif int(sales_item.get("type")) == 2:
                                            service_info['可领取预约金优惠券'].append(sales_item.get("desc"))
                                        else:
                                            pass
                                    service_info['query词'] = query
                                    service_info['城市'] = city_name
                                    service_info['平台'] = "更美"
                                    service_info[
                                        '链接'] = "https://m.igengmei.com/promotion/{}?sku_id={}&distribute_type=1&distribute_id=30775628&is_share=1".format(
                                        service_info['美购id'], service_info['skuid'])
                                    print(service_info)
                                    get_data_file.write(json.dumps(service_info))
                                    get_data_file.write("\n")
                                else:
                                    other_city_count += 1

                        else:
                            print("break")
                            break_flat = True
                            break
            else:
                print(city_name, query, "爬取失败")
        else:
            print(page, city_name, query, "本地已爬完")


def main(city_tag=""):
    begin = time.time()
    nowday = datetime.datetime.now()
    today = str(nowday).split()[0]
    file_name = "gengmei_save_data_" + str(today) + city_tag + ".txt"

    get_data_file = open(file_name, "a+", encoding="utf-8")

    cityIdMapping = {'北京': '328', '上海': '9', '重庆': '22', '广州市': '289', '深圳市': '291', '郑州市': '240', '武汉市': '258',
                     '长沙市': '275', '南京市': '162', '成都市': '385', '西安市': '438', '杭州市': '175'}

    keywords = ['瘦脸针', '双眼皮', '光子嫩肤', '吸脂', '水光针', '玻尿酸', '热玛吉',
                '脱毛', '瘦腿针', '鼻综合', '瘦肩针', '下颌角', '线雕', '超声刀',
                '美白针', '眼综合', '隆鼻', '菲洛嘉', '下巴', '热拉提', '点阵激光',
                '面部吸脂', '开内眼角', '嗨体', '牙齿矫正', '皮秒', '超皮秒', '植发',
                '黄金微针', '隆胸', '微针', '光子嫩肤', '祛斑', '小气泡', '嗨体熊猫针',
                '熊猫针', '果酸焕肤', '自体脂肪隆胸', '7D聚拉提', '瘦脸', '埋线双眼皮',
                '菲洛嘉水光针', '双眼皮修复', '欧洲之星', '脂肪填充', '溶脂针', '法令纹',
                '鼻基底', '全切双眼皮', '颧骨内推', '鼻子', '光子嫩肤m22', '下颌缘提升',
                'm22', '鼻翼缩小', '欧洲之星fotona4d', '自体脂肪全面部填充', '玻尿酸丰唇',
                '水光', '嗨体祛颈纹', '假体隆胸', '英诺小棕瓶', '黄金微雕', '眼袋', '乔雅登',
                '除皱', '颧骨', '艾莉薇', '抽脂', '瘦腿', '玻尿酸丰下巴', '纹眉', '伊肤泉微针',
                '美白', '厚唇改薄', '面部线雕', '祛疤', '伊婉V', '超皮秒祛斑', '除皱针', '开眼角',
                '海菲秀', '假体下巴', '刷酸', '泪沟', '拉皮', '全身吸脂', '缩鼻翼']

    # city_list = ["beijing", "shanghai", "guangzhou", "shenzhen", "hangzhou", "chengdu", "chongqing", "nanjing", "wuhan", "changsha", "zhengzhou", "xian"]
    city_list = ["北京", "上海", "广州", "深圳", "杭州", "成都", "重庆", "南京", "武汉", "长沙", "郑州", "西安"]

    city_list = [city_tag]

    for city_name in city_list:
        for word in keywords:
            get_service_info(query=word, city_name="".join(lazy_pinyin(city_name)), get_data_file=get_data_file)

    get_data_file.close()
    print(time.time() - begin)


if __name__ == '__main__':
    args = sys.argv[1]
    main(city_tag=args)
